@@ -7,14 +7,11 @@ def first_time_set_up(up):
     up.fetch_vars()
     print("Latest values of Dynamic Variables fetched from internet !\n")
     print("If you want to change Chrome Driver Path or update Dynamic Variables")
-    print("     then please visit    aahnik.github.io/wapp-driver ")
+    print("     then please visit    aahnik.github.io/wappdriver ")
 
 
 def convey(error, message):
     print(f"\n {message} \n")
-    print("For Help Contact Aahnik Daw, the author...")
-    print("Email: aahnikdaw@gmail.com \n")
-    print("\t\tPress ENTER to skip")
+    print(f'\n{error}\n')
+    print("\n For help visit aahnik.github.io/wappdriver ")
 
-    if input("Enter d to see details about Exceptions caught.\n") == 'd':
-        print(f'\n{error}\n')
